@@ -86,33 +86,35 @@ if (sizeof($files) < 1) {
 $tabindex = 1;
 ?>
 	</head>
-	<body class="admin">
+	<body>
 		<?php
 			printJsIncludes('../..');
 			?>
-		<table border=0 width="100%" class="lamHeader ui-corner-all">
-			<tr>
-				<td align="left" height="30">
-					<a class="lamLogo" href="http://www.ldap-account-manager.org/" target="new_window">
-						<?php echo getLAMVersionText(); ?>
-					</a>
-				</td>
-                <td align="right">
-					<?php
-					if (is_dir(__DIR__ . '/../../docs/manual')) {
-						?>
-                        <a target="_blank" href="../../docs/manual/index.html"><img class="align-middle" width="16" height="16" alt="help" src="../../graphics/help.png">
-                            <span class="hide-on-tablet">&nbsp;</span>
-                            <span class="hide-on-mobile">
-                            <?php echo _("Help") ?>&nbsp;&nbsp;&nbsp;&nbsp;
-                            </span>
-                        </a>
-						<?php
-					}
-					?>
-                </td>
-			</tr>
-		</table>
+        <div id="lam-topnav" class="lam-header">
+            <div class="lam-header-left lam-menu-stay">
+                <a href="https://www.ldap-account-manager.org/" target="new_window">
+                    <img class="align-middle" width="24" height="24" alt="help" src="../../graphics/logo24.png">
+                    <span class="hide-on-mobile">
+                        <?php
+                        echo getLAMVersionText();
+                        ?>
+                    </span>
+                </a>
+            </div>
+			<?php
+			if (is_dir(dirname(__FILE__) . '/../../docs/manual')) {
+				?>
+                <a class="lam-header-right lam-menu-icon hide-on-tablet" href="javascript:void(0);" class="icon" onclick="window.lam.topmenu.toggle();">
+                    <img class="align-middle" width="16" height="16" alt="menu" src="../../graphics/menu.svg">
+                    <span class="padding0">&nbsp;</span>
+                </a>
+                <a class="lam-header-right lam-menu-entry" target="_blank" href="../../docs/manual/index.html">
+                    <span class="padding0"><?php echo _("Help") ?></span>
+                </a>
+				<?php
+			}
+			?>
+        </div>
 		<br><br>
 		<!-- form to change existing profiles -->
 		<form action="confmain.php" method="post" autocomplete="off">
@@ -148,13 +150,14 @@ $tabindex = 1;
 			$box->add($passwordInput, 12);
 			$box->addVerticalSpacer('1rem');
 			$button = new htmlButton('submit', _("Ok"));
+			$button->setCSSClasses(array('lam-primary'));
 			$box->addLabel($button);
 			$box->add(new htmlOutputText(''), 0, 6);
 			$box->addVerticalSpacer('1.5rem');
 			$box->add(new htmlHorizontalLine(), 12);
 			$box->addVerticalSpacer('1.5rem');
 		}
-		$manageLink = new htmlLink(_("Manage server profiles"), 'profmanage.php', '../../graphics/tools.png');
+		$manageLink = new htmlLink(_("Manage server profiles"), 'profmanage.php');
 		$box->add($manageLink, 12, 12, 12, 'text-center');
 
 		$boxDiv = new htmlDiv(null, $box);
@@ -163,7 +166,7 @@ $tabindex = 1;
 
 		// back link
 		$row->addVerticalSpacer('2rem');
-		$backLink = new htmlLink(_("Back to login"), '../login.php', '../../graphics/undo.png');
+		$backLink = new htmlLink(_("Back to login"), '../login.php');
 		$row->add($backLink, 12, 12, 12, 'text-left');
 
 		parseHtml(null, new htmlDiv(null, $row, array('centeredTable')), array(), false, $tabindex, 'user');
