@@ -176,7 +176,7 @@ echo "</html>\n";
 * @param \LAM\TYPES\ConfiguredType $type account type
 * @param htmlResponsiveRow $container meta HTML container
 */
-function config_showAccountModules($type, &$container) {
+function config_showAccountModules($type, &$container): void {
 	// account modules
 	$available = getAvailableModules($type->getScope(), true);
 	$selected = $type->getModules();
@@ -234,9 +234,10 @@ function config_showAccountModules($type, &$container) {
 			$el->addElement($delButton);
 			$listElements[] = $el;
 		}
-		$selSortable = new htmlSortableList($listElements, $type->getId() . '_selected', null);
+		$selSortable = new htmlSortableList($listElements, $type->getId() . '_selected');
 		$selSortable->alignment = htmlElement::ALIGN_TOP;
-		$selSortable->setOnUpdate('updateModulePositions(\'positions_' . $type->getId() . '\', ui.item.data(\'posOrig\'), ui.item.index());');
+		$selSortable->setCSSClasses(array('module-list'));
+		$selSortable->setOnUpdate('function() {updateModulePositions(\'positions_' . $type->getId() . '\', \'' . $type->getId() . '_selected' . '\');}');
 		$container->add($selSortable, 12, 6);
 	}
 	else {
@@ -275,9 +276,9 @@ function config_showAccountModules($type, &$container) {
 /**
  * Checks user input and saves the entered settings.
  *
- * @return array list of errors
+ * @return array<mixed> list of errors
  */
-function checkInput() {
+function checkInput(): array {
 	if (!isset($_POST['postAvailable'])) {
 		return array();
 	}
