@@ -2,7 +2,7 @@
 /*
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2020  Roland Gruber
+  Copyright (C) 2003 - 2021  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -68,7 +68,7 @@ echo $_SESSION['header'];
 printHeaderContents(_("Login"), '../..');
 ?>
 	</head>
-	<body class="admin">
+	<body>
 		<?php
 			// include all JavaScript files
 			$jsDirName = dirname(__FILE__) . '/../lib';
@@ -83,29 +83,31 @@ printHeaderContents(_("Login"), '../..');
 				echo "<script type=\"text/javascript\" src=\"../lib/" . $jsEntry . "\"></script>\n";
 			}
 		?>
-		<table border=0 width="100%" class="lamHeader ui-corner-all">
-			<tr>
-				<td align="left" height="30">
-					<a class="lamLogo" href="http://www.ldap-account-manager.org/" target="new_window">
-						<?php echo getLAMVersionText(); ?>
-					</a>
-				</td>
-                <td align="right">
-					<?php
-					if (is_dir(__DIR__ . '/../../docs/manual')) {
-						?>
-                        <a target="_blank" href="../../docs/manual/index.html"><img class="align-middle" width="16" height="16" alt="help" src="../../graphics/help.png">
-                            <span class="hide-on-tablet">&nbsp;</span>
-                            <span class="hide-on-mobile">
-                            <?php echo _("Help") ?>&nbsp;&nbsp;&nbsp;&nbsp;
-                            </span>
-                        </a>
-						<?php
-					}
-					?>
-                </td>
-			</tr>
-		</table>
+        <div id="lam-topnav" class="lam-header">
+            <div class="lam-header-left lam-menu-stay">
+                <a href="https://www.ldap-account-manager.org/" target="new_window">
+                    <img class="align-middle" width="24" height="24" alt="help" src="../../graphics/logo24.png">
+                    <span class="hide-on-mobile">
+                        <?php
+                        echo getLAMVersionText();
+                        ?>
+                    </span>
+                </a>
+            </div>
+			<?php
+			if (is_dir(dirname(__FILE__) . '/../../docs/manual')) {
+				?>
+                <a class="lam-header-right lam-menu-icon hide-on-tablet" href="javascript:void(0);" class="icon" onclick="window.lam.topmenu.toggle();">
+                    <img class="align-middle" width="16" height="16" alt="menu" src="../../graphics/menu.svg">
+                    <span class="padding0">&nbsp;</span>
+                </a>
+                <a class="lam-header-right lam-menu-entry" target="_blank" href="../../docs/manual/index.html">
+                    <span class="padding0"><?php echo _("Help") ?></span>
+                </a>
+				<?php
+			}
+			?>
+        </div>
 		<br>
 		<?php
 			// check if config file is writable
@@ -157,6 +159,7 @@ printHeaderContents(_("Login"), '../..');
 		// button
 		$group->addElement($spacer);
 		$okButton = new htmlButton('submit', _("Ok"));
+		$okButton->setCSSClasses(array('lam-primary'));
 		$row = new htmlResponsiveRow();
 		$row->add($okButton, 12);
 		$row->setCSSClasses(array(''));
@@ -172,7 +175,7 @@ printHeaderContents(_("Login"), '../..');
 		</table>
 		</td></tr>
 		<tr><td align="left">
-		<br><a href="../login.php"><IMG alt="configuration" src="../../graphics/undo.png">&nbsp;<?php echo _("Back to login"); ?> </a>
+		<br><a href="../login.php"><?php echo _("Back to login"); ?></a>
 		</td></tr>
 		</table>
 		</form>
