@@ -170,30 +170,32 @@ echo $_SESSION['header'];
 printHeaderContents(_("Profile management"), '../..');
 ?>
 	</head>
-	<body class="admin">
-		<table border=0 width="100%" class="lamHeader ui-corner-all">
-			<tr>
-				<td align="left" height="30">
-					<a class="lamLogo" href="http://www.ldap-account-manager.org/" target="new_window">
-						<?php echo getLAMVersionText(); ?>
-					</a>
-				</td>
-                <td align="right">
-					<?php
-					if (is_dir(__DIR__ . '/../../docs/manual')) {
-						?>
-                        <a target="_blank" href="../../docs/manual/index.html"><img class="align-middle" width="16" height="16" alt="help" src="../../graphics/help.png">
-                            <span class="hide-on-tablet">&nbsp;</span>
-                            <span class="hide-on-mobile">
-                            <?php echo _("Help") ?>&nbsp;&nbsp;&nbsp;&nbsp;
-                            </span>
-                        </a>
-						<?php
-					}
-					?>
-                </td>
-			</tr>
-		</table>
+	<body>
+    <div id="lam-topnav" class="lam-header">
+        <div class="lam-header-left lam-menu-stay">
+            <a href="https://www.ldap-account-manager.org/" target="new_window">
+                <img class="align-middle" width="24" height="24" alt="help" src="../../graphics/logo24.png">
+                <span class="hide-on-mobile">
+                        <?php
+                        echo getLAMVersionText();
+                        ?>
+                    </span>
+            </a>
+        </div>
+		<?php
+		if (is_dir(dirname(__FILE__) . '/../../docs/manual')) {
+			?>
+            <a class="lam-header-right lam-menu-icon hide-on-tablet" href="javascript:void(0);" class="icon" onclick="window.lam.topmenu.toggle();">
+                <img class="align-middle" width="16" height="16" alt="menu" src="../../graphics/menu.svg">
+                <span class="padding0">&nbsp;</span>
+            </a>
+            <a class="lam-header-right lam-menu-entry" target="_blank" href="../../docs/manual/index.html">
+                <span class="padding0"><?php echo _("Help") ?></span>
+            </a>
+			<?php
+		}
+		?>
+    </div>
 
 <?php
 // include all JavaScript files
@@ -250,6 +252,7 @@ $addTemplateSelect->setHasDescriptiveElements(true);
 $box->add($addTemplateSelect, 12);
 $box->addVerticalSpacer('0.5rem');
 $newProfileButton = new htmlButton('btnAddProfile', _('Add'));
+$newProfileButton->setCSSClasses(array('lam-primary'));
 $newProfileButton->setOnClick("jQuery('#action').val('add');showConfirmationDialog('" . _("Add profile") . "', '" .
 	_('Ok') . "', '" . _('Cancel') . "', 'passwordDialogDiv', 'profileForm', null); document.getElementById('passwd').focus();");
 $box->addLabel($newProfileButton);
@@ -262,6 +265,7 @@ $oldProfileInput = new htmlResponsiveInputField(_('New profile name'), 'renfilen
 $box->add($oldProfileInput, 12);
 $box->addVerticalSpacer('0.5rem');
 $renameProfileButton = new htmlButton('btnRenameProfile', _('Rename'));
+$renameProfileButton->setCSSClasses(array('lam-secondary'));
 $renameProfileButton->setOnClick("jQuery('#action').val('rename');showConfirmationDialog('" . _("Rename profile") . "', '" .
 	_('Ok') . "', '" . _('Cancel') . "', 'passwordDialogDiv', 'profileForm', null); document.getElementById('passwd').focus();");
 $box->addLabel($renameProfileButton);
@@ -272,6 +276,7 @@ $box->add(new htmlSubTitle(_("Delete profile")), 12);
 $box->add(new htmlResponsiveSelect('delfilename', $files, array(), _('Profile name'), '232'), 12);
 $box->addVerticalSpacer('0.5rem');
 $deleteProfileButton = new htmlButton('btnDeleteProfile', _('Delete'));
+$deleteProfileButton->setCSSClasses(array('lam-danger'));
 $deleteProfileButton->setOnClick("jQuery('#action').val('delete');showConfirmationDialog('" . _("Delete profile") . "', '" .
 	_('Ok') . "', '" . _('Cancel') . "', 'passwordDialogDiv', 'profileForm', null); document.getElementById('passwd').focus();");
 $box->addLabel($deleteProfileButton);
@@ -289,6 +294,7 @@ $profileSetPwd2->setSameValueFieldID('setpassword');
 $box->add($profileSetPwd2, 12);
 $box->addVerticalSpacer('0.5rem');
 $setPasswordProfileButton = new htmlButton('btnSetPasswordProfile', _('Set profile password'));
+$setPasswordProfileButton->setCSSClasses(array('lam-secondary'));
 $setPasswordProfileButton->setOnClick("jQuery('#action').val('setpass');showConfirmationDialog('" . _("Set profile password") . "', '" .
 		_('Ok') . "', '" . _('Cancel') . "', 'passwordDialogDiv', 'profileForm', null); document.getElementById('passwd').focus();");
 $box->addLabel($setPasswordProfileButton, 12);
@@ -302,6 +308,7 @@ $box->add(new htmlSubTitle(_("Change default profile")), 12);
 $box->add(new htmlResponsiveSelect('defaultfilename', $files, array($defaultprofile), _('Profile name'), '234'), 12);
 $box->addVerticalSpacer('0.5rem');
 $defaultProfileButton = new htmlButton('btnDefaultProfile', _('Ok'));
+$defaultProfileButton->setCSSClasses(array('lam-secondary'));
 $defaultProfileButton->setOnClick("jQuery('#action').val('setdefault');showConfirmationDialog('" . _("Change default profile") . "', '" .
 	_('Ok') . "', '" . _('Cancel') . "', 'passwordDialogDiv', 'profileForm', null); document.getElementById('passwd').focus();");
 $box->addLabel($defaultProfileButton);
@@ -323,7 +330,7 @@ $dialogDiv->setCSSClasses(array('hidden'));
 $row->add($dialogDiv, 12);
 
 $row->addVerticalSpacer('2rem');
-$backLink = new htmlLink(_("Back to profile login"), 'conflogin.php', '../../graphics/undo.png');
+$backLink = new htmlLink(_("Back to profile login"), 'conflogin.php');
 $row->add($backLink, 12, 12, 12, 'text-left');
 
 parseHtml('', new htmlDiv(null, $row, array('centeredTable')), array(), false, $tabindex, 'user');
