@@ -643,27 +643,18 @@ function checkPasswordStrengthHandleReply(data, fieldID) {
  * Updates the positions of a htmlSortable list in a hidden input field.
  * The positions must be separated by comma (e.g. "0,1,2,3").
  *
- * @param id HTML ID of hidden input field
- * @param oldPos old position
- * @param newPos new position
+ * @param inputId HTML ID of hidden input field
+ * @param containerId HTML ID of ul-container
  */
-function updateModulePositions(id, oldPos, newPos) {
-	var positions = jQuery('#' + id).val().split(',');
-	if (newPos > oldPos) {
-		var save = positions[oldPos];
-		for (var i = oldPos; i < newPos; i++) {
-			positions[i] = positions[i + 1];
-		}
-		positions[newPos] = save;
+function updateModulePositions(inputId, containerId) {
+	const input = document.getElementById(inputId);
+	let positions = [];
+	const container = document.getElementById(containerId);
+	const childLiElements = container.children;
+	for (let i = 0; i < childLiElements.length; i++) {
+		positions[i] = childLiElements[i].getAttribute('data-position-orig');
 	}
-	if (newPos < oldPos) {
-		var oldPosition = positions[oldPos];
-		for (var position = oldPos; position > newPos; position--) {
-			positions[position] = positions[position - 1];
-		}
-		positions[newPos] = oldPosition;
-	}
-	jQuery('#' + id).val(positions.join(','));
+	input.value = positions.join(',');
 }
 
 window.lam.filterSelect = window.lam.filterSelect || {};
@@ -2329,6 +2320,9 @@ window.lam.treeview.findAttributeChanges = function () {
 	jQuery('.single-input').each(
 		function() {
 			var input = jQuery(this);
+			if (input.is(":hidden")) {
+				return;
+			}
 			var attrName = input.data('attr-name');
 			// avoid type conversion in .data()
 			var valueOrig = input.attr('data-value-orig');
@@ -2353,6 +2347,9 @@ window.lam.treeview.findAttributeChanges = function () {
 	jQuery('.multi-input').each(
 		function() {
 			var input = jQuery(this);
+			if (input.is(":hidden")) {
+				return;
+			}
 			var attrName = input.data('attr-name');
 			if (attrName != lastAttrName) {
 				if (lastAttrHasChange) {
@@ -2549,8 +2546,8 @@ window.lam.treeview.addAttributeField = function (event, select) {
 	attributeParts = attributeParts.split('__#__');
 	var attributeName = attributeParts[0];
 	var isSingleValue = attributeParts[1];
-	var isMultiline = attributeParts[2];
-	var placeHolderId = 'new-attributes-' + isSingleValue + '-' + isMultiline;
+	var fieldType = attributeParts[2];
+	var placeHolderId = 'new-attributes-' + isSingleValue + '-' + fieldType;
 	var newContent = jQuery(jQuery('#' + placeHolderId).children('.row').get(0)).clone();
 	jQuery(newContent.children().get(0)).text(attributeName);
 	var inputField = newContent.find('input, textarea');
@@ -2728,6 +2725,7 @@ window.lam.treeview.pasteNode = function (tokenName, tokenValue, node, tree) {
 		window.lam.treeview.checkSession(jsonData);
 		if (jsonData.error) {
 			jQuery('#ldap_actionarea_messages').html(jsonData.error);
+			return;
 		}
 		tree.set_icon(dn, oldIcon);
 		window.sessionStorage.removeItem('LAM_COPY_PASTE_ACTION');
@@ -2803,6 +2801,20 @@ window.lam.treeview.checkPassword = function(event, element, tokenName, tokenVal
 	});
 }
 
+/**
+ * Updates the positions of a sorted list of LDAP values.
+ *
+ * @param containerId HTML ID of ul-container
+ */
+window.lam.treeview.updateAttributePositionData = function(containerId) {
+	const container = document.getElementById(containerId);
+	const childLiElements = container.children;
+	for (let i = 0; i < childLiElements.length; i++) {
+		const inputField = childLiElements[i].querySelector('input');
+		inputField.value = '{' + i + '}' + inputField.value.replace(/^\{[0-9]+\}/, '');
+	}
+}
+
 window.lam.topmenu = window.lam.topmenu || {};
 
 /**
