@@ -1,5 +1,5 @@
 /**
- * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -78,13 +78,13 @@ CKEDITOR.lang[ 'en-au' ] = {
 		width: 'Width',
 		height: 'Height',
 		align: 'Align',
-		left: 'Left', // MISSING
-		right: 'Right', // MISSING
-		center: 'Center', // MISSING
-		justify: 'Justify', // MISSING
-		alignLeft: 'Align Left', // MISSING
-		alignRight: 'Align Right', // MISSING
-		alignCenter: 'Align Center', // MISSING
+		left: 'Left',
+		right: 'Right',
+		center: 'Centre',
+		justify: 'Justify',
+		alignLeft: 'Align Left',
+		alignRight: 'Align Right',
+		alignCenter: 'Align Centre',
 		alignTop: 'Top',
 		alignMiddle: 'Middle',
 		alignBottom: 'Bottom',
