@@ -1,5 +1,5 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'clipboard', 'ru', {
@@ -10,6 +10,5 @@ CKEDITOR.plugins.setLang( 'clipboard', 'ru', {
 	paste: 'Вставить',
 	pasteNotification: 'Для вставки нажмите %1. Ваш браузер не поддерживает возможность вставки через панель инструментов или контекстное меню',
 	pasteArea: 'Область вставки',
-	pasteMsg: 'Вставьте контент в эту область и нажмите OK',
-	title: 'Вставить'
+	pasteMsg: 'Вставьте контент в эту область и нажмите OK'
 } );
