@@ -1,12 +1,12 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'font', 'ku', {
 	fontSize: {
-		label: 'گەورەیی',
-		voiceLabel: 'گەورەیی فۆنت',
-		panelTitle: 'گەورەیی فۆنت'
+		label: 'قەبارە',
+		voiceLabel: 'قەبارەی فۆنت',
+		panelTitle: 'قەبارەی فۆنت'
 	},
 	label: 'فۆنت',
 	panelTitle: 'ناوی فۆنت',
