@@ -1,14 +1,14 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'font', 'sr-latn', {
 	fontSize: {
-		label: 'Veličina fonta',
-		voiceLabel: 'Font Size',
-		panelTitle: 'Veličina fonta'
+		label: 'Veličina ',
+		voiceLabel: 'Veličina slova',
+		panelTitle: 'Veličina slova'
 	},
 	label: 'Font',
-	panelTitle: 'Font',
+	panelTitle: 'Naziv fonta',
 	voiceLabel: 'Font'
 } );
