@@ -1,5 +1,5 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'iframe', 'eu', {
@@ -7,5 +7,6 @@ CKEDITOR.plugins.setLang( 'iframe', 'eu', {
 	noUrl: 'Idatzi iframe-aren URLa, mesedez.',
 	scrolling: 'Gaitu korritze-barrak',
 	title: 'IFrame-aren propietateak',
-	toolbar: 'IFrame-a'
+	toolbar: 'IFrame-a',
+	tabindex: 'Remove from tabindex' // MISSING
 } );
