@@ -1,5 +1,5 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'iframe', 'it', {
@@ -7,5 +7,6 @@ CKEDITOR.plugins.setLang( 'iframe', 'it', {
 	noUrl: 'Inserire l\'URL del campo IFrame',
 	scrolling: 'Abilita scrollbar',
 	title: 'Proprietà IFrame',
-	toolbar: 'IFrame'
+	toolbar: 'IFrame',
+	tabindex: 'Rimuovi da tabindex'
 } );
