@@ -1,12 +1,12 @@
 ﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'link', 'bg', {
-	acccessKey: 'Ключ за достъп',
+	acccessKey: 'Клавиш за достъп',
 	advanced: 'Разширено',
-	advisoryContentType: 'Препоръчителен тип на съдържанието',
-	advisoryTitle: 'Препоръчително заглавие',
+	advisoryContentType: 'Тип на съдържанието',
+	advisoryTitle: 'Заглавие',
 	anchor: {
 		toolbar: 'Котва',
 		menu: 'Промяна на котва',
@@ -17,25 +17,27 @@ CKEDITOR.plugins.setLang( 'link', 'bg', {
 	},
 	anchorId: 'По ID на елемент',
 	anchorName: 'По име на котва',
-	charset: 'Тип на свързания ресурс',
-	cssClasses: 'Класове за CSS',
-	download: 'Force Download', // MISSING
-	displayText: 'Display Text', // MISSING
-	emailAddress: 'E-mail aдрес',
+	charset: 'Езиков код на свързания ресурс',
+	cssClasses: 'CSS класове',
+	download: 'Укажи изтегляне',
+	displayText: 'Текст за показване',
+	emailAddress: 'Имейл aдрес',
 	emailBody: 'Съдържание',
 	emailSubject: 'Тема',
-	id: 'ID',
-	info: 'Инфо за връзката',
-	langCode: 'Код за езика',
+	id: 'Id',
+	info: 'Връзка',
+	langCode: 'Езиков код',
 	langDir: 'Посока на езика',
-	langDirLTR: 'Ляво на Дясно (ЛнД)',
-	langDirRTL: 'Дясно на Ляво (ДнЛ)',
+	langDirLTR: 'От ляво надясно (LTR)',
+	langDirRTL: 'От дясно наляво (RTL)',
 	menu: 'Промяна на връзка',
 	name: 'Име',
 	noAnchors: '(Няма котви в текущия документ)',
-	noEmail: 'Моля въведете e-mail aдрес',
-	noUrl: 'Моля въведете URL адреса',
+	noEmail: 'Моля въведете имейл адрес',
+	noUrl: 'Моля въведете URL адрес',
+	noTel: 'Please type the phone number', // MISSING
 	other: '<друго>',
+	phoneNumber: 'Phone number', // MISSING
 	popupDependent: 'Зависимост (Netscape)',
 	popupFeatures: 'Функции на изкачащ прозорец',
 	popupFullScreen: 'Цял екран (IE)',
@@ -43,23 +45,24 @@ CKEDITOR.plugins.setLang( 'link', 'bg', {
 	popupLocationBar: 'Лента с локацията',
 	popupMenuBar: 'Лента за меню',
 	popupResizable: 'Оразмеряем',
-	popupScrollBars: 'Скролери',
+	popupScrollBars: 'Ленти за прелистване',
 	popupStatusBar: 'Статусна лента',
 	popupToolbar: 'Лента с инструменти',
 	popupTop: 'Горна позиция',
-	rel: 'Връзка',
+	rel: 'Свързаност (rel атрибут)',
 	selectAnchor: 'Изберете котва',
 	styles: 'Стил',
 	tabIndex: 'Ред на достъп',
 	target: 'Цел',
 	targetFrame: '<frame>',
-	targetFrameName: 'Име на целевият прозорец',
+	targetFrameName: 'Име на целевия прозорец',
 	targetPopup: '<изкачащ прозорец>',
 	targetPopupName: 'Име на изкачащ прозорец',
 	title: 'Връзка',
 	toAnchor: 'Връзка към котва в текста',
-	toEmail: 'E-mail',
+	toEmail: 'Имейл',
 	toUrl: 'Уеб адрес',
+	toPhone: 'Phone', // MISSING
 	toolbar: 'Връзка',
 	type: 'Тип на връзката',
 	unlink: 'Премахни връзката',
