@@ -1,5 +1,5 @@
 ﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'link', 'cy', {
@@ -35,7 +35,9 @@ CKEDITOR.plugins.setLang( 'link', 'cy', {
 	noAnchors: '(Dim angorau ar gael yn y ddogfen)',
 	noEmail: 'Teipiwch gyfeiriad yr e-bost',
 	noUrl: 'Teipiwch URL y ddolen',
+	noTel: 'Please type the phone number', // MISSING
 	other: '<eraill>',
+	phoneNumber: 'Phone number', // MISSING
 	popupDependent: 'Dibynnol (Netscape)',
 	popupFeatures: 'Nodweddion Ffenestr Bop',
 	popupFullScreen: 'Sgrin Llawn (IE)',
@@ -60,6 +62,7 @@ CKEDITOR.plugins.setLang( 'link', 'cy', {
 	toAnchor: 'Dolen at angor yn y testun',
 	toEmail: 'E-bost',
 	toUrl: 'URL',
+	toPhone: 'Phone', // MISSING
 	toolbar: 'Dolen',
 	type: 'Math y Ddolen',
 	unlink: 'Datgysylltu',
