@@ -1,5 +1,5 @@
 ﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'link', 'mn', {
@@ -35,7 +35,9 @@ CKEDITOR.plugins.setLang( 'link', 'mn', {
 	noAnchors: '(Баримт бичиг зангуугүй байна)',
 	noEmail: 'Э-шуудангий хаягаа шивнэ үү',
 	noUrl: 'Холбоосны URL хаягийг шивнэ үү',
+	noTel: 'Please type the phone number', // MISSING
 	other: '<other>', // MISSING
+	phoneNumber: 'Phone number', // MISSING
 	popupDependent: 'Хамаатай (Netscape)',
 	popupFeatures: 'Popup цонхны онцлог',
 	popupFullScreen: 'Цонх дүүргэх (Internet Explorer)',
@@ -60,6 +62,7 @@ CKEDITOR.plugins.setLang( 'link', 'mn', {
 	toAnchor: 'Энэ бичвэр дэх зангуу руу очих холбоос',
 	toEmail: 'Э-захиа',
 	toUrl: 'цахим хуудасны хаяг (URL)',
+	toPhone: 'Phone', // MISSING
 	toolbar: 'Холбоос',
 	type: 'Линкийн төрөл',
 	unlink: 'Холбоос авч хаях',
