@@ -1,5 +1,5 @@
 ﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'link', 'ug', {
@@ -35,7 +35,9 @@ CKEDITOR.plugins.setLang( 'link', 'ug', {
 	noAnchors: '(بۇ پۈتۈكتە ئىشلەتكىلى بولىدىغان لەڭگەرلىك نۇقتا يوق)',
 	noEmail: 'ئېلخەت ئادرېسىنى كىرگۈزۈڭ',
 	noUrl: 'ئۇلانما ئادرېسىنى كىرگۈزۈڭ',
+	noTel: 'Please type the phone number', // MISSING
 	other: '‹باشقا›',
+	phoneNumber: 'Phone number', // MISSING
 	popupDependent: 'تەۋە (NS)',
 	popupFeatures: 'قاڭقىش كۆزنەك خاسلىقى',
 	popupFullScreen: 'پۈتۈن ئېكران (IE)',
@@ -60,6 +62,7 @@ CKEDITOR.plugins.setLang( 'link', 'ug', {
 	toAnchor: 'بەت ئىچىدىكى لەڭگەرلىك نۇقتا ئۇلانمىسى',
 	toEmail: 'ئېلخەت',
 	toUrl: 'ئادرېس',
+	toPhone: 'Phone', // MISSING
 	toolbar: 'ئۇلانما قىستۇر/تەھرىرلە',
 	type: 'ئۇلانما تىپى',
 	unlink: 'ئۇلانما بىكار قىل',
