@@ -1,5 +1,5 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'table', 'da', {
@@ -50,6 +50,7 @@ CKEDITOR.plugins.setLang( 'table', 'da', {
 	headersColumn: 'Første kolonne',
 	headersNone: 'Ingen',
 	headersRow: 'Første række',
+	heightUnit: 'højde enhed',
 	invalidBorder: 'Rammetykkelse skal være et tal.',
 	invalidCellPadding: 'Cellemargen skal være et tal.',
 	invalidCellSpacing: 'Celleafstand skal være et tal.',
