@@ -1,5 +1,5 @@
-﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+/*
+Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'table', 'ku', {
@@ -50,6 +50,7 @@ CKEDITOR.plugins.setLang( 'table', 'ku', {
 	headersColumn: 'یەکەم ئەستوون',
 	headersNone: 'هیچ',
 	headersRow: 'یەکەم ڕیز',
+	heightUnit: 'یەکەی بەرز',
 	invalidBorder: 'ژمارەی پەراوێز دەبێت تەنها ژماره بێت.',
 	invalidCellPadding: 'ناوپۆشی خانه دەبێت ژمارەکی درووست بێت.',
 	invalidCellSpacing: 'بۆشایی خانه دەبێت ژمارەکی درووست بێت.',
