@@ -88,7 +88,7 @@ try {
 // save last selected login profile
 if (isset($_GET['useProfile'])) {
 	if (in_array($_GET['useProfile'], $profiles)) {
-		setcookie("lam_default_profile", $_GET['useProfile'], time() + 365*60*60*24, '/', null, null, true);
+		setcookie("lam_default_profile", $_GET['useProfile'], time() + 365*60*60*24, '/', '', false, true);
 	}
 	else {
 		unset($_GET['useProfile']);
@@ -97,7 +97,7 @@ if (isset($_GET['useProfile'])) {
 
 // save last selected language
 if (isset($_POST['language'])) {
-	setcookie('lam_last_language', htmlspecialchars($_POST['language']), time() + 365*60*60*24, '/', null, null, true);
+	setcookie('lam_last_language', htmlspecialchars($_POST['language']), time() + 365*60*60*24, '/', '', false, true);
 }
 
 // init some session variables
@@ -174,10 +174,15 @@ $_SESSION['header'] .= "<html>\n<head>\n";
 $_SESSION['header'] .= "<meta name=\"robots\" content=\"noindex, nofollow\">\n";
 $_SESSION['header'] .= "<meta http-equiv=\"content-type\" content=\"text/html; charset=" . $encoding . "\">\n";
 $_SESSION['header'] .= "<meta http-equiv=\"pragma\" content=\"no-cache\">\n		<meta http-equiv=\"cache-control\" content=\"no-cache\">";
-$manifestUrl = str_replace('/templates/login.php', '', getCallingURL());
-$manifestUrl = preg_replace('/http(s)?:\\/\\/([^\\/])+/', '', $manifestUrl);
-$manifestUrl = preg_replace('/\\?.*/', '', $manifestUrl);
-$_SESSION['header'] .= '<link rel="manifest" href="' . $manifestUrl . '/templates/manifest.php" crossorigin="use-credentials">';
+$manifestBaseUrl = getCallingURL();
+if (strpos($manifestBaseUrl, '/templates/login.php') !== false) {
+    $manifestBaseUrl = substr($manifestBaseUrl, 0, strpos($manifestBaseUrl, '/templates/login.php'));
+	$urlMatches = array();
+	if (preg_match('/^http(s)?:\\/\\/[^\\/]+(\\/.*)$/m', $manifestBaseUrl, $urlMatches)) {
+	    $manifestBaseUrl = htmlspecialchars($urlMatches[2]);
+		$_SESSION['header'] .= '<link rel="manifest" href="' . $manifestBaseUrl . '/templates/manifest.php" crossorigin="use-credentials">';
+	}
+}
 
 setlanguage(); // setting correct language
 
@@ -190,18 +195,16 @@ setlanguage(); // setting correct language
  * @param string $extraMessage extra message that is shown as info
  * @throws LAMException error rendering login page
  */
-function display_LoginPage($licenseValidator, $error_message, $errorDetails = null, $extraMessage = null) {
+function display_LoginPage($licenseValidator, $error_message, $errorDetails = null, $extraMessage = null): void {
 	$config_object = $_SESSION['config'];
 	$cfgMain = $_SESSION["cfgMain"];
 	logNewMessage(LOG_DEBUG, "Display login page");
 	// generate 256 bit key and initialization vector for user/passwd-encryption
-	if (function_exists('openssl_random_pseudo_bytes') && ($cfgMain->encryptSession == 'true')) {
-		$key = openssl_random_pseudo_bytes(32);
-		$iv = openssl_random_pseudo_bytes(16);
-		// save both in cookie
-		setcookie("Key", base64_encode($key), 0, "/", null, null, true);
-		setcookie("IV", base64_encode($iv), 0, "/", null, null, true);
-	}
+    $key = openssl_random_pseudo_bytes(32);
+    $iv = openssl_random_pseudo_bytes(16);
+    // save both in cookie
+    setcookie("Key", base64_encode($key), 0, "/", '', false, true);
+    setcookie("IV", base64_encode($iv), 0, "/", '', false, true);
 
 	$serverProfilePersistenceManager = new ServerProfilePersistenceManager();
 	$profiles = $serverProfilePersistenceManager->getProfiles();
@@ -518,10 +521,10 @@ if (isset($_POST['checklogin'])) {
 	}
 	else {
 		if (isset($_POST['rememberLogin']) && ($_POST['rememberLogin'] == 'on')) {
-			setcookie('lam_login_name', $_POST['username'], time() + 60*60*24*365, '/', null, null, true);
+			setcookie('lam_login_name', $_POST['username'], time() + 60*60*24*365, '/', '', false, true);
 		}
 		else if (isset($_COOKIE['lam_login_name']) && ($_SESSION['config']->getLoginMethod() == LAMConfig::LOGIN_SEARCH)) {
-			setcookie('lam_login_name', '', time() + 60*60*24*365, '/', null, null, true);
+			setcookie('lam_login_name', '', time() + 60*60*24*365, '/', '', false, true);
 		}
 		if($_POST['passwd'] == "") {
 			logNewMessage(LOG_DEBUG, "Empty password for login");
@@ -537,7 +540,7 @@ if (isset($_POST['checklogin'])) {
     $searchLDAP = null;
 	if ($_SESSION['config']->getLoginMethod() == LAMConfig::LOGIN_SEARCH) {
 		$searchFilter = $_SESSION['config']->getLoginSearchFilter();
-		$searchFilter = str_replace('%USER%', $username, $searchFilter);
+		$searchFilter = str_replace('%USER%', ldap_escape($username, '', LDAP_ESCAPE_FILTER), $searchFilter);
 		$searchDN = '';
 		$searchPassword = '';
 		$configLoginSearchDn = $_SESSION['config']->getLoginSearchDN();
@@ -553,9 +556,9 @@ if (isset($_POST['checklogin'])) {
             $searchResult = ldap_search($searchLDAP->server(), $_SESSION['config']->getLoginSearchSuffix(), $searchFilter, array('dn'), 0, 0, 0, LDAP_DEREF_NEVER);
             if ($searchResult) {
                 $searchInfo = ldap_get_entries($searchLDAP->server(), $searchResult);
-                if ($searchInfo) {
+                if ($searchInfo !== false) {
                     cleanLDAPResult($searchInfo);
-                    if (sizeof($searchInfo) == 0) {
+                    if (empty($searchInfo)) {
                         $searchSuccess = false;
                         $searchError = _('Wrong password/user name combination. Please try again.');
 	                    header("HTTP/1.1 403 Forbidden");
