@@ -7,7 +7,7 @@ use \htmlTitle;
 /*
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2006 - 2018  Roland Gruber
+  Copyright (C) 2006 - 2021  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -42,24 +42,26 @@ startSecureSession();
 enforceUserIsLoggedIn();
 
 // die if no write access
-if (!checkIfWriteAccessIsAllowed()) die();
+if (!checkIfWriteAccessIsAllowed()) {
+	die();
+}
 
 checkIfToolIsActive('toolTests');
 
 setlanguage();
 
 include '../../lib/adminHeader.inc';
-echo "<div class=\"user-bright smallPaddingContent\">\n";
+echo "<div class=\"smallPaddingContent\">\n";
 
 $container = new htmlResponsiveRow();
 $container->add(new htmlTitle(_("LAM tests")), 12);
 
-$container->add(new htmlLink(_("Lamdaemon test"), 'lamdaemonTest.php', '../../graphics/lamdaemonSmall.png'), 12, 4);
+$container->add(new htmlLink(_("Lamdaemon test"), 'lamdaemonTest.php', '../../graphics/script.svg'), 12, 4);
 $container->add(new htmlOutputText(_("Check if quotas and homedirectories can be managed.")), 12, 8);
 
 $container->addVerticalSpacer('2rem');
 
-$container->add(new htmlLink(_("Schema test"), 'schemaTest.php', '../../graphics/schemaTest.png'), 12, 4);
+$container->add(new htmlLink(_("Schema test"), 'schemaTest.php', '../../graphics/search-color.svg'), 12, 4);
 $container->add(new htmlOutputText(_("Check if the LDAP schema fits the requirements of the selected account modules.")), 12, 8);
 
 $tabindex = 1;
@@ -67,5 +69,3 @@ parseHtml(null, $container, array(), true, $tabindex, 'user');
 
 echo "</div>\n";
 include '../../lib/adminFooter.inc';
-
-?>
