@@ -116,7 +116,7 @@ if (isset($_POST['createOU']) || isset($_POST['deleteOU'])) {
 		// check for sub entries
 		$sr = ldap_list($_SESSION['ldap']->server(), $_POST['deleteableOU'], "ObjectClass=*", array(""));
 		$info = ldap_get_entries($_SESSION['ldap']->server(), $sr);
-		if ($sr && $info['count'] == 0) {
+		if ($sr && ($info['count'] === 0)) {
 			// print header
 			include '../../lib/adminHeader.inc';
 			echo '<div class="smallPaddingContent">';
@@ -156,10 +156,10 @@ display_main($message, $error);
 /**
  * Displays the main page of the OU editor
  *
- * @param String $message info message
- * @param String $error error message
+ * @param string|null $message info message
+ * @param string|null $error error message
  */
-function display_main($message, $error) {
+function display_main(?string $message, ?string $error): void {
 	// display main page
 	include __DIR__ . '/../../lib/adminHeader.inc';
 	echo '<div class="smallPaddingContent">';
