@@ -66,7 +66,7 @@ else {
 echo '</div>';
 include __DIR__ . '/../../lib/adminFooter.inc';
 
-function showTree() {
+function showTree(): void {
 	$openInitial = array();
 	if (isset($_GET['dn'])) {
 		$initialDn = base64_decode($_GET['dn']);
@@ -269,5 +269,5 @@ function showTree() {
 
 	$tabIndex = 1;
 	$form = new htmlForm('actionarea', 'treeView.php', $row);
-	parseHtml(null, $form, array(), true, $tabIndex, 'none');
+	parseHtml(null, $form, array(), true, $tabIndex, null);
 }
